## design nest

This Python library allows to read, modify and create and run EnergyPlus file and simulations. Component file generation concept from [pyidf](https://github.com/rbuffat/pyidf) but instead of idd schema, we are using the new json schema.

## Installation
 
### pip:
```
pip install design_nest
```

## Documentation
Comming Soon

## Sample Usage
Comming Soon